==> cloud-8.x-1.2.tar.gz: cloud/modules/cloud_service_providers/k8s/tests/src/Functional/K8sSecretTest.php <==
<?php

namespace Drupal\Tests\k8s\Functional;

/**
 * Tests K8s secret.
 *
 * @group K8s
 */
class K8sSecretTest extends K8sTestBase {

  public const K8S_SECRET_REPEAT_COUNT = 2;

  /**
   * {@inheritdoc}
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   * @throws \Exception
   */
  protected function getPermissions(): array {
    $namespaces = $this->createNamespacesRandomTestFormData();
    $this->createNamespaceTestEntity($namespaces[0]);
    $this->namespace = $namespaces[0]['name'];

    return [
      'list k8s secret',
      'view k8s secret',
      'edit k8s secret',
      'add k8s secret',
      'delete k8s secret',
      'view k8s namespace ' . $this->namespace,
    ];
  }

  /**
   * Tests CRUD for Secret.
   *
   * @throws \Behat\Mink\Exception\ExpectationException
   */
  public function testSecret() {

    $cloud_context = $this->cloudContext;

    // List Secret for K8s.
    $this->drupalGet("/clouds/k8s/$cloud_context/secret");
    $this->assertNoErrorMessage();

    // Add a new Secret.
    $add = $this->createSecretTestFormData(self::K8S_SECRET_REPEAT_COUNT, $this->namespace);
    for ($i = 0; $i < self::K8S_SECRET_REPEAT_COUNT; $i++) {
      $this->reloadMockData();

      $this->addSecretMockData($add[$i]);

      $this->drupalPostForm(
        "/clouds/k8s/$cloud_context/secret/add",
        $add[$i]['post_data'],
        $this->t('Save')
      );
      $this->assertNoErrorMessage();
      $t_args = ['@type' => 'Secret', '%label' => $add[$i]['name']];
      $this->assertSession()->pageTextContains(strip_tags($this->t('The @type %label has been created.', $t_args)));

      // Make sure listing.
      $this->drupalGet("/clouds/k8s/$cloud_context/secret");
      $this->assertNoErrorMessage();
      $this->assertSession()->pageTextContains($add[$i]['name']);
    }

    for ($i = 0, $num = 1; $i < self::K8S_SECRET_REPEAT_COUNT; $i++, $num++) {
      // Make sure the all secret listing exists.
      $this->drupalGet('/clouds/k8s/secret');
      $this->assertNoErrorMessage();

      for ($j = 0; $j < $num; $j++) {
        $this->assertSession()->pageTextContains($add[$j]['name']);
      }
    }

    // Edit a Secret.
    $edit = $this->createSecretTestFormData(self::K8S_SECRET_REPEAT_COUNT, $this->namespace);
    for ($i = 0, $num = 1; $i < self::K8S_SECRET_REPEAT_COUNT; $i++, $num++) {

      $this->updateSecretMockData($edit[$i]);

      unset($edit[$i]['post_data']['namespace']);
      $this->drupalPostForm(
        "/clouds/k8s/$cloud_context/secret/$num/edit",
        $edit[$i]['post_data'],
        $this->t('Save')
      );
      $this->assertNoErrorMessage();
      $t_args = ['@type' => 'Secret', '%label' => $add[$i]['name']];
      $this->assertSession()->pageTextContains(strip_tags($this->t('The @type %label has been updated.', $t_args)));
    }

    // Delete Secret.
    for ($i = 0, $num = 1; $i < self::K8S_SECRET_REPEAT_COUNT; $i++, $num++) {

      $this->deleteSecretMockData($add[$i]);

      $this->drupalPostForm(
        "/clouds/k8s/$cloud_context/secret/$num/delete",
        [],
        $this->t('Delete')
      );
      $this->assertNoErrorMessage();
      $t_args = ['@type' => 'Secret', '@label' => $add[$i]['name']];
      $this->assertSession()->pageTextContains(strip_tags($this->t('The @type @label has been deleted.', $t_args)));

      // Make sure listing.
      $this->drupalGet("/clouds/k8s/$cloud_context/secret");
      $this->assertNoErrorMessage();
      $this->assertSession()->pageTextNotContains($add[$i]['name']);
    }
  }

  /**
   * Tests deleting secrets with bulk operation.
   *
   * @throws \Exception
   */
  public function testSecretBulk(): void {

    for ($i = 0; $i < self::K8S_SECRET_REPEAT_COUNT; $i++) {
      // Create Secrets.
      $secrets = $this->createSecretsRandomTestFormData($this->namespace);
      $entities = [];
      foreach ($secrets ?: [] as $secret) {
        $entities[] = $this->createSecretTestEntity($secret);
      }
      $this->deleteSecretMockData($secrets[0]);
      $this->runTestEntityBulk('secret', $entities);
    }
  }

}

==> cloud-8.x-2.0-rc1.tar.gz: cloud/modules/cloud_service_providers/k8s/tests/src/Functional/K8sSecretTest.php <==
<?php

namespace Drupal\Tests\k8s\Functional;

/**
 * Tests K8s secret.
 *
 * @group K8s
 */
class K8sSecretTest extends K8sTestCase {

  public const K8S_SECRET_REPEAT_COUNT = 3;

  /**
   * {@inheritdoc}
   */
  protected function getPermissions() {
    $namespaces = $this->createNamespacesRandomTestFormData();
    $this->createNamespaceTestEntity($namespaces[0]);
    $this->namespace = $namespaces[0]['name'];

    return [
      'list k8s secret',
      'view k8s secret',
      'edit k8s secret',
      'add k8s secret',
      'delete k8s secret',
      'view k8s namespace ' . $this->namespace,
    ];
  }

  /**
   * Tests CRUD for Secret.
   */
  public function testSecret() {

    $cloud_context = $this->cloudContext;

    // List Secret for K8s.
    $this->drupalGet("/clouds/k8s/$cloud_context/secret");
    $this->assertResponse(200);

    // Add a new Secret.
    $add = $this->createSecretTestFormData(self::K8S_SECRET_REPEAT_COUNT, $this->namespace);
    for ($i = 0; $i < self::K8S_SECRET_REPEAT_COUNT; $i++) {
      $this->reloadMockData();

      $this->addSecretMockData($add[$i]);

      $num = $i + 1;
      $this->drupalPostForm(
        "/clouds/k8s/$cloud_context/secret/add",
        $add[$i]['post_data'],
        $this->t('Save')
      );
      $this->assertResponse(200);
      $this->assertText($this->t('Kubernetes Secret @name has been created.', ['@name' => $add[$i]['name']]));

      // Make sure listing.
      $this->drupalGet("/clouds/k8s/$cloud_context/secret");
      $this->assertResponse(200);
      $this->assertText($add[$i]['name']);
    }

    // Edit a Secret.
    $edit = $this->createSecretTestFormData(self::K8S_SECRET_REPEAT_COUNT, $this->namespace);
    for ($i = 0; $i < self::K8S_SECRET_REPEAT_COUNT; $i++) {
      $num = $i + 1;
      $this->updateSecretMockData($edit[$i]);

      unset($edit[$i]['post_data']['namespace']);
      $this->drupalPostForm(
        "/clouds/k8s/$cloud_context/secret/$num/edit",
        $edit[$i]['post_data'],
        $this->t('Save')
      );
      $this->assertResponse(200);
      $this->assertText($this->t(
        'Kubernetes Secret @name has been updated.',
        ['@name' => $add[$i]['name']]
      ));
    }

    // Delete Secret.
    for ($i = 0; $i < self::K8S_SECRET_REPEAT_COUNT; $i++) {
      $num = $i + 1;

      $this->deleteSecretMockData($add[$i]);

      $this->drupalPostForm(
        "/clouds/k8s/$cloud_context/secret/$num/delete",
        [],
        $this->t('Delete')
      );
      $this->assertResponse(200);
      $this->assertText($this->t(
        'The Kubernetes Secret @name has been deleted.',
        ['@name' => $add[$i]['name']]
      ));

      // Make sure listing.
      $this->drupalGet("/clouds/k8s/$cloud_context/secret");
      $this->assertResponse(200);
      $this->assertNoText($add[$i]['name']);
    }
  }

  /**
   * Tests deleting secrets with bulk operation.
   */
  public function testSecretBulk() {

    for ($i = 0; $i < self::K8S_SECRET_REPEAT_COUNT; $i++) {
      // Create Secrets.
      $secrets = $this->createSecretsRandomTestFormData($this->namespace);
      $entities = [];
      foreach ($secrets as $secret) {
        $entities[] = $this->createSecretTestEntity($secret);
      }
      $this->deleteSecretMockData($secrets[0]);
      $this->doTestEntityBulk('secret', $entities);
    }
  }

}
